@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 # Mathmaker Lib offers lualatex-printable mathematical objects.
-# Copyright 2006-2017 Nicolas Hainaux <nh.techn@gmail.com>
+# Copyright 2006-2019 Nicolas Hainaux <nh.techn@gmail.com>
 
 # This file is part of Mathmaker Lib.
 
@@ -45,7 +45,7 @@ class Sign(Printable, Evaluable):
         return 'Sign({})'.format(self.sign)
 
     def __str__(self):
-        return self.sign
+        return str(self.sign)
 
     def __eq__(self, other):
         if isinstance(other, Sign):
@@ -358,7 +358,7 @@ class Number(Decimal, Signed, Printable, Evaluable):
         else:
             return Sign('+')
 
-    def imprint(self, start_expr=True, variant='latex'):
+    def imprint(self, start_expr=True, variant='latex', dot=False):
         extra_sign = ''
         if not start_expr and self >= 0:
             extra_sign = '+'
@@ -374,6 +374,9 @@ class Number(Decimal, Signed, Printable, Evaluable):
             raise ValueError('variant must belong to [\'latex\', \'siunitx\', '
                              '\'user_input\']; got \'{}\' instead.'
                              .format(variant))
+        if dot:
+            self_str = self_str\
+                .replace(locale.localeconv()['decimal_point'], '.')
         if self.unit is None:
             if variant == 'siunitx':
                 required.package['siunitx'] = True
